@@ -44,6 +44,12 @@ df <- read_csv(my_report.file)
 
 #### Reformat data files ####
 
+### Change all metadata columns to factors to avoid problems at plotting
+
+for(i in 2:ncol(metadata)){
+  metadata[,i] <- factor(as_vector(metadata[,i])) 
+}
+
 # Intensity data file
 
 matrix <- matrix[metadata$SampleID,]
@@ -108,7 +114,6 @@ ggsave(filename, nmds_plot, dpi = 300)
 
 set.seed(456)
 
-dm.method = "bray"
 dist.matrix <- vegdist(matrix , method = dm.method) # dist matrix
 
 permanova <- adonis(dist.matrix ~ %group1% + %group2%, 
@@ -153,16 +158,16 @@ pca_plot <- ggplot(pca_coordinates,
   geom_segment(data = var_loadings,
                aes(x = 0,
                    y = 0,
-                   xend = Dim.1 * 5,
-                   yend = Dim.2 * 5, 
+                   xend = Dim.1 * 2,
+                   yend = Dim.2 * 2, 
                    color = name), 
                inherit.aes = FALSE,
                arrow = arrow(length = unit(0.03, 'npc')),
                size = 0.8) +
   scale_color_manual(values = class_color) +
   geom_text(data = var_loadings,
-            aes(x = ifelse(Dim.1 * 5 > 0, Dim.1 * 5 + 1, Dim.1 * 5 - 1),
-                y = ifelse(Dim.2 * 5 > 0, Dim.2 * 5 + 1, Dim.2 * 5 - 1),
+            aes(x = ifelse(Dim.1 * 2 > 0, Dim.1 * 2 + 1, Dim.1 * 2 - 1),
+                y = ifelse(Dim.2 * 2 > 0, Dim.2 * 2 + 1, Dim.2 * 2 - 1),
                 label = name,
                 color = name),
             inherit.aes = FALSE,
@@ -241,16 +246,16 @@ pca_plot <- ggplot(pca_coordinates,
   geom_segment(data = var_loadings,
                aes(x = 0,
                    y = 0,
-                   xend = Dim.1 * 2,
-                   yend = Dim.2 * 2, 
+                   xend = Dim.1 * 1,
+                   yend = Dim.2 * 1, 
                    color = name), 
                inherit.aes = FALSE,
                arrow = arrow(length = unit(0.03, 'npc')),
                size = 0.8) +
   scale_color_manual(values = class_color) +
   geom_text(data = var_loadings,
-            aes(x = ifelse(Dim.1 * 2 > 0, Dim.1 * 5 + 1, Dim.1 * 5 - 1),
-                y = ifelse(Dim.2 * 2 > 0, Dim.2 * 5 + 1, Dim.2 * 5 - 1),
+            aes(x = ifelse(Dim.1 * 1 > 0, Dim.1 * 1 + 1, Dim.1 * 1 - 1),
+                y = ifelse(Dim.2 * 1 > 0, Dim.2 * 1 + 1, Dim.2 * 1 - 1),
                 label = name,
                 color = name),
             inherit.aes = FALSE,
